@@ -104,7 +104,7 @@ class Rule:
         self._metadata = []
         for option in self._options:
             if option.name == Option.MSG:
-                self._msg = option.value
+                self._msg = option.value.strip('"')
             elif option.name == Option.SID:
                 self._sid = int(option.value)
             elif option.name == Option.GID:
@@ -142,6 +142,9 @@ class Rule:
         self.build_rule()
         return chosen_options
 
+    def get_option(self, name):
+        return [option for option in self.options if option.name == name]
+
     def to_dict(self):
         options = []
         for option in self.options:
